@@ -13,7 +13,9 @@ V. Network extraction
 VI. Internal functions
 
 Note:
-     Go to network_selection.py for all selection-related functions
+     See the ``Network Selection`` section for all selection-related functions.
+
+     See the ``Utils`` section for functions that convert node and edge names to SUIDs, and vice versa.
 """
 
 """Copyright 2020 The Cytoscape Consortium
@@ -183,11 +185,11 @@ def get_network_name(suid=None, base_url=DEFAULT_BASE_URL):
         >>> get_network_name('galFiltered.sif') # verify that current network is galFiltered.sif
         galFiltered.sif
 
-    Notes:
-        Together with getNetworkSuid, this function attempts to handle all
+    Note:
+        Together with get_network_suid, this function attempts to handle all
         of the multiple ways we support network referencing (e.g., title, SUID,
         'current', and NULL). These functions are then used by all other functions
-        that take a "network" argument.
+        that take a ``network`` argument.
     """
     if isinstance(suid, str):
         # title provided
@@ -473,8 +475,7 @@ def get_first_neighbors(node_names=None, as_nested_list=False, network=None, bas
 
     for node_name in node_names:
         # get first neighbors for each node
-        node_suid = node_name_to_node_suid([node_name], net_suid, base_url=base_url)[0]
-        # TODO: Verify that this won't break if node_name_to_node_suid returns a list instead of a scalar ... I think it will break ... should we except??
+        node_suid = node_name_to_node_suid([node_name], net_suid, base_url=base_url, unique_list=True)[0]
 
         first_neighbors_suids = commands.cyrest_get(
             f'networks/{net_suid}/nodes/{node_suid}/neighbors', base_url=base_url)
@@ -878,7 +879,7 @@ def create_network_from_igraph(igraph, title='From igraph', collection='My Igrap
                                base_url=DEFAULT_BASE_URL):
     """Create a Cytoscape network from an igraph network.
 
-    Takes an igraph network and generates data frames for nodes and edges to
+    Takes an igraph network and generates dataframes for nodes and edges to
     send to the createNetwork function. Returns the network.suid and applies the perferred
     layout set in Cytoscape preferences.
 
@@ -915,8 +916,6 @@ def create_network_from_igraph(igraph, title='From igraph', collection='My Igrap
         >>> g.add_vertices(3)
         >>> g.vs['name'] = ['RAP1', 'HIS4', 'HIS3']
         >>> g.add_edges([(0, 1), (1, 2)])
-        >>> g.es['source'] = [g.vs[0]['name'], g.vs[1]['name']]
-        >>> g.es['target'] = [g.vs[1]['name'], g.vs[2]['name']]
         >>> g.es['interaction'] = ['enhances', 'inhibits']
         >>> create_network_from_igraph(g, 'new graph', 'my collection')
         138775
@@ -929,29 +928,45 @@ def create_network_from_igraph(igraph, title='From igraph', collection='My Igrap
     # TODO: Verify the undeclared parameter behaviors claimed in the R documents
     # TODO: Is this really faithful to the R implementation?
 
-    def attrs_present(entity_collection):
-        attrs = set()
-        for entity in entity_collection:
-            attrs |= set(entity.attributes().keys())
-        return attrs
+    def rename_dup_columns(col_list, col_name):
+        # See if a column name exists, and if so, rename all other same-name columns.
+        # Especially important for graphs that come with a ``source`` or ``target`` name
+        # created by get_edge_dataframe (which creates these columns) when these columns
+        # were already in the graph as a result of creating the graph from a Cytoscape
+        # network.
+        first_index = col_list.index(col_name)
+        replacement_name = col_name + '.original'
+        new_cols = [replacement_name if i != first_index and col_list[i] == col_name else col_list[i] for i in range(len(col_list))]
+        return new_cols
 
-    def copy_attrs_to_dataframe(entity_collection):
-        df = pd.DataFrame()
-        for col in attrs_present(entity_collection):
-            df[col] = entity_collection[col]
-        return df
-
-    node_df = copy_attrs_to_dataframe(igraph.vs)
-    edge_df = copy_attrs_to_dataframe(igraph.es)
-
-    # Make sure critical attributes are strings
+    # Get nodes as a table indexed by node number ... assume every node has at least a 'name' attribute as a string
+    node_df = ig.Graph.get_vertex_dataframe(igraph)
     node_df['name'] = node_df['name'].astype(str)
-    edge_df['source'] = edge_df['source'].astype(str)
-    edge_df['target'] = edge_df['target'].astype(str)
+
+    # Get edges as a table ... assume every edge has a 'source' and 'target' column as indexes into node table
+    edge_df = ig.Graph.get_edge_dataframe(igraph)
+    # Make sure interaction is a string
     if 'interaction' in edge_df.columns: edge_df['interaction'] = edge_df['interaction'].astype(str)
 
+    try:
+        # If the incoming graph contained a column named 'source' or 'target', rename them
+        edge_cols = rename_dup_columns(list(edge_df.columns), 'source')
+        edge_df.columns = rename_dup_columns(edge_cols, 'target')
+    except:
+        narrate('Edge table missing "source" or "target" attribute') # iGraph creates this df, so should never happen
+        edge_df = None
+
+    if edge_df is not None:
+        try:
+            # Convert edge 'source' and 'target' values from index into node table to actual node name
+            edge_df['source'] = edge_df['source'].apply(lambda x: node_df['name'][x])
+            edge_df['target'] = edge_df['target'].apply(lambda x: node_df['name'][x])
+        except:
+            narrate('Not all edge sources or targets resolve to vertex names') # iGraph creates this df, so should never happen
+            edge_df = None
+
     if len(node_df.index) == 0: node_df = None
-    if len(edge_df.index) == 0: edge_df = None
+    if edge_df is not None and len(edge_df.index) == 0: edge_df = None
 
     return create_network_from_data_frames(nodes=node_df, edges=edge_df, title=title, collection=collection,
                                            base_url=base_url, node_id_list='name')
@@ -963,7 +978,7 @@ def create_network_from_networkx(netx, title='From networkx', collection='My Net
     """Create a Cytoscape network from a NetworkX graph.
 
     Args:
-        netx (MultiDiGraph): networkx MultiDiGraph object
+        netx (Graph, DiGraph, MultiGraph or MultiDiGraph): networkx object
         title (str): network name
         collection (str): network collection name
         base_url (str): Ignore unless you need to specify a custom domain,
@@ -989,8 +1004,8 @@ def create_network_from_networkx(netx, title='From networkx', collection='My Net
     netx_node_list = [{**attrs, 'name': name}    for name, attrs in netx_nodes]
     node_df = pd.DataFrame.from_records(netx_node_list)
 
-    netx_edges = netx.out_edges(data=True, keys=True) # returns list of tuples (src, targ, suid, attrs)
-    netx_edge_list = [{**attrs, 'source': src, 'target': targ}    for src, targ, suid, attrs in netx_edges]
+    netx_edges = netx.edges(data=True) # returns list of tuples (src, targ, attrs)
+    netx_edge_list = [{**attrs, 'source': src, 'target': targ}    for src, targ, attrs in netx_edges]
     edge_df = pd.DataFrame.from_records(netx_edge_list)
 
     # TODO: This will blow if there are no edges or no nodes ... so will create_network_from_igraph() ... will R blow, too?
@@ -1124,7 +1139,7 @@ def create_network_from_data_frames(nodes=None, edges=None, title='From datafram
                       zip(edges[source_id_list], edges[interaction_type_list], edges[target_id_list])]
         edges['name'] = edge_names
         # find out the SUID of each node so it can be used in a multigraph if needed
-        edges['data.key.column'] = edge_name_to_edge_suid(edge_names, network_suid, base_url=base_url)
+        edges['data.key.column'] = edge_name_to_edge_suid(edge_names, network_suid, base_url=base_url, unique_list=True)
 
         # if the edge list looks real, add the edge attributes (if any)
         if len(set(edges.columns) - set(['source', 'target', 'interaction', 'name', 'data.key.column'])) != 0:
@@ -1146,13 +1161,17 @@ def create_network_from_data_frames(nodes=None, edges=None, title='From datafram
 def import_network_from_tabular_file(file=None, first_row_as_column_names=False, start_load_row=1, column_type_list='s,i,t', delimiters='\\,,\t', base_url=DEFAULT_BASE_URL):
     """Loads a network from specified file.
 
+    Note:
+        To load a tabular file from cloud storage, use the file's URL and the ``sandbox_url_to`` function to download
+        the file to a sandbox, and then use ``import_network_from_tabular_file`` to load it from there.
+
     Args:
         file (str): Name of file in any of the supported tabular formats (e.g., csv, tsv, Excel, etc).
         first_row_as_column_names (bool): True if first row contributes column names but no data values
         start_load_row (int): 1-based row to start reading data ... after column name row, if present
         column_type_list (str): comma-separated map of column types ordered by column index
             (e.g. "source,target,interaction,source attribute,target attribute,edge attribute,skip" or just "s,t,i,sa,ta,ea,x"); defaults to "s,i,t"
-        delimiters (str): comma-separated list of characters that can separate columns ... \\, is a comma, \t is a tab
+        delimiters (str): comma-separated list of characters that can separate columns ... ``\\\\,`` is a comma, ``\\t`` is a tab
         base_url (str): Ignore unless you need to specify a custom domain,
             port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
@@ -1177,6 +1196,7 @@ def import_network_from_tabular_file(file=None, first_row_as_column_names=False,
         >>>                                  column_type_list='s,t,x,i',
         >>>                                  delimiters=' ')
         {'networks': [131481], 'views': [131850]}
+
     """
     file = get_abs_sandbox_path(file)
 
@@ -1214,6 +1234,11 @@ def import_network_from_tabular_file(file=None, first_row_as_column_names=False,
 @cy_log
 def import_network_from_file(file=None, base_url=DEFAULT_BASE_URL):
     """Loads a network from specified file.
+
+    Note:
+        To load a network file from cloud storage, use the file's URL and the ``sandbox_url_to`` function to download
+        the file to a sandbox, and then use ``import_network_from_file`` to load it from there.
+
     Args:
         file (str): Name of file in any of the supported formats (e.g., SIF, GML, xGMML, etc).
             If None, a demo network file in SIF format is loaded.
@@ -1222,9 +1247,11 @@ def import_network_from_file(file=None, base_url=DEFAULT_BASE_URL):
             and the latest version of the CyREST API supported by this version of py4cytoscape.
     Returns:
         dict: {"networks": [network suid], "views": [suid for views]} where networks and views lists have length 1
+
     Raises:
         CyError: if file cannot be found or loaded
         requests.exceptions.RequestException: if can't connect to Cytoscape or Cytoscape returns an error
+
     Examples:
         >>> import_network_from_file() # import demo network
         {'networks': [131481], 'views': [131850]}
@@ -1257,8 +1284,7 @@ def create_igraph_from_network(network=None, base_url=DEFAULT_BASE_URL):
     """Create an igraph network from a Cytoscape network.
 
     Notes:
-        Takes a Cytoscape network and generates data frames for vertices and edges to send to the graph_from_data_frame
-        function. Nodes and edges from the Cytoscape network will be translated into vertices and edges in igraph.
+        Takes a Cytoscape network and translates it nodes and edges into vertices and edges in igraph.
         Associated table columns will also be passed to igraph as vertex and edge attributes. All networks are
         implicitly modeled as directed in Cytoscape. Round-trip conversion of an undirected network in igraph via
         ``createNetworkFromIgraph`` to Cytoscape and back to igraph will result in a directed network.
@@ -1306,9 +1332,9 @@ def create_igraph_from_network(network=None, base_url=DEFAULT_BASE_URL):
 
     # check for source and target columns ... if they're not present, dig them out of the full name
     if not {'source', 'target'} <= set(cyedges.columns):
-        src_trg = [re.split("\ \\(.*\\)\ ", x) for x in cyedges['name']]
+        src_trg = parse_edges(cyedges['name'])
         cyedges['source'] = [x[0] for x in src_trg]
-        cyedges['target'] = [x[1] for x in src_trg]
+        cyedges['target'] = [x[2] for x in src_trg]
 
     # set up iGraph vertices ... first create vertex by naming it, then pile on attributes
     # Tutorial: https://igraph.org/python/doc/tutorial/tutorial.html
@@ -1323,7 +1349,7 @@ def create_igraph_from_network(network=None, base_url=DEFAULT_BASE_URL):
     # add all edges and their nodes
     g.add_edges([(src, trg) for src, trg in zip(cyedges['source'], cyedges['target'])])
     # TODO: Find out why this rename happens ... is this an iGraph thing? ... how does the roundtrip work?
-    cyedges.rename({'source': 'from', 'target': 'to'})
+    # cyedges.rename(columns={'source': 'from', 'target': 'to'}, inplace=True)
     for col in cyedges.columns:
         if not col in ['SUID']: g.es[col] = list(cyedges[col])
 
@@ -1369,9 +1395,9 @@ def create_networkx_from_network(network=None, base_url=DEFAULT_BASE_URL):
 
     # check for source and target columns ... if they're not present, dig them out of the full name
     if not {'source', 'target'} <= set(cyedges.columns):
-        src_trg = [re.split("\ \\(.*\\)\ ", x) for x in cyedges['name']]
+        src_trg = parse_edges(cyedges['name'])
         cyedges['source'] = [x[0] for x in src_trg]
-        cyedges['target'] = [x[1] for x in src_trg]
+        cyedges['target'] = [x[2] for x in src_trg]
 
     # Create a list of edges as tuples (src, targ, suid, attrs) with 'source' & 'target' removed from attrs
     edges_dict = cyedges.to_dict(orient='records')
